# 用于记录使用中的想法和问题

1、关于在模拟器中的拓扑环境制造故障的问题。
    - 需要明确告诉LLM, “你可以调用工具对拓扑中的设备进行任意操作制造一个故障。”
    ~~- 需要配置no ip domain-lookup命令。这样可以让llm多执行几个exit命令，退出到用户模式，会刷屏一下，我们不会直接看到llm制造故障的配置。~~ 关掉console窗口就行了。不要去点开工具的调用过程看。 就可以让LLM制造故障，自己练习了。